#!perl -w

use strict;
use Getopt::Long;
use Time::HiRes qw(gettimeofday);
use Data::Collection qw/read_directory/;
use Data::Collection::Search qw/search elapsed_time show_search_help/;

Getopt::Long::Configure ("bundling_override");

#######################
# Option variable with default value (false)

my ($help, $version, $search_term, $case_sens, %options) = ( '', '', '', '', () );

GetOptions ('help!' => \$help, 'h!' => \$help, 'search_term|term=s' => \$search_term, 't=s' => \$search_term,
'case_sens|case=s' => \$case_sens, 'c=s' => \$case_sens, 'version!' => \$version, 'v!' => \$version);

#######################
# Retrieve command-line options

$options{help} = $help;
$options{version} = $version;
$options{search_term} = $search_term;
$options{case_sens} = $case_sens;

Data::Collection::Search->show_search_help() if ( $help );
Data::Collection::Search->show_search_version() if ( $version );

my ($sec_start, $usec_start) = gettimeofday(); #get seconds and microseconds since the epoch

my ($report_loc, $number, $disks) = Data::Collection::Search->search(\$search_term, \$case_sens);

my ($sec_finish, $usec_finish) = gettimeofday(); #get seconds and microseconds since the epoch
my $time_ref = Data::Collection::Search->elapsed_time($sec_start,$usec_start,$sec_finish,$usec_finish);	

print ($$number > 0 ? sprintf(qq{\tThe search returned }. $$number .qq{ result%s for '}. $search_term .qq{' in %0.3f seconds on @$disks.  The  You can view the XML report in $$report_loc.\n\n},( $$number == 1 ? '' : 's' ), $$time_ref) : sprintf(qq{\tThe term '$search_term' could not be found in %0.3f seconds.\n\n}, $$time_ref));	

exit(0);




